==> ruff-0.0.246.tar.gz: ruff-0.0.246/crates/ruff/src/rules/flake8_simplify/rules/mod.rs <==
pub use ast_bool_op::{
    a_and_not_a, a_or_not_a, and_false, compare_with_tuple, duplicate_isinstance_call, or_true,
    AAndNotA, AOrNotA, AndFalse, CompareWithTuple, DuplicateIsinstanceCall, OrTrue,
};
pub use ast_expr::{use_capital_environment_variables, UseCapitalEnvironmentVariables};
pub use ast_for::{convert_for_loop_to_any_all, ConvertLoopToAll, ConvertLoopToAny};
pub use ast_if::{
    if_with_same_arms, nested_if_statements, return_bool_condition_directly,
    use_dict_get_with_default, use_ternary_operator, CollapsibleIf, DictGetWithDefault,
    IfWithSameArms, NeedlessBool, UseTernaryOperator,
};
pub use ast_ifexp::{
    explicit_false_true_in_ifexpr, explicit_true_false_in_ifexpr, twisted_arms_in_ifexpr,
    IfExprWithFalseTrue, IfExprWithTrueFalse, IfExprWithTwistedArms,
};
pub use ast_unary_op::{
    double_negation, negation_with_equal_op, negation_with_not_equal_op, DoubleNegation,
    NegateEqualOp, NegateNotEqualOp,
};
pub use ast_with::{multiple_with_statements, MultipleWithStatements};
pub use key_in_dict::{key_in_dict_compare, key_in_dict_for, KeyInDict};
pub use open_file_with_context_handler::{
    open_file_with_context_handler, OpenFileWithContextHandler,
};
pub use return_in_try_except_finally::{return_in_try_except_finally, ReturnInTryExceptFinally};
pub use use_contextlib_suppress::{use_contextlib_suppress, UseContextlibSuppress};
pub use yoda_conditions::{yoda_conditions, YodaConditions};

mod ast_bool_op;
mod ast_expr;
mod ast_for;
mod ast_if;
mod ast_ifexp;
mod ast_unary_op;
mod ast_with;
mod fix_if;
mod fix_with;
mod key_in_dict;
mod open_file_with_context_handler;
mod return_in_try_except_finally;
mod use_contextlib_suppress;
mod yoda_conditions;

==> ruff-0.0.253.tar.gz: ruff-0.0.253/crates/ruff/src/rules/flake8_simplify/rules/mod.rs <==
pub use ast_bool_op::{
    compare_with_tuple, duplicate_isinstance_call, expr_and_false, expr_and_not_expr,
    expr_or_not_expr, expr_or_true, CompareWithTuple, DuplicateIsinstanceCall, ExprAndFalse,
    ExprAndNotExpr, ExprOrNotExpr, ExprOrTrue,
};
pub use ast_expr::{use_capital_environment_variables, UseCapitalEnvironmentVariables};
pub use ast_if::{
    if_with_same_arms, manual_dict_lookup, needless_bool, nested_if_statements,
    use_dict_get_with_default, use_ternary_operator, CollapsibleIf, DictGetWithDefault,
    IfWithSameArms, ManualDictLookup, NeedlessBool, UseTernaryOperator,
};
pub use ast_ifexp::{
    explicit_false_true_in_ifexpr, explicit_true_false_in_ifexpr, twisted_arms_in_ifexpr,
    IfExprWithFalseTrue, IfExprWithTrueFalse, IfExprWithTwistedArms,
};
pub use ast_unary_op::{
    double_negation, negation_with_equal_op, negation_with_not_equal_op, DoubleNegation,
    NegateEqualOp, NegateNotEqualOp,
};
pub use ast_with::{multiple_with_statements, MultipleWithStatements};
pub use key_in_dict::{key_in_dict_compare, key_in_dict_for, KeyInDict};
pub use open_file_with_context_handler::{
    open_file_with_context_handler, OpenFileWithContextHandler,
};
pub use reimplemented_builtin::{convert_for_loop_to_any_all, ReimplementedBuiltin};
pub use return_in_try_except_finally::{return_in_try_except_finally, ReturnInTryExceptFinally};
pub use use_contextlib_suppress::{use_contextlib_suppress, UseContextlibSuppress};
pub use yoda_conditions::{yoda_conditions, YodaConditions};

mod ast_bool_op;
mod ast_expr;
mod ast_if;
mod ast_ifexp;
mod ast_unary_op;
mod ast_with;
mod fix_if;
mod fix_with;
mod key_in_dict;
mod open_file_with_context_handler;
mod reimplemented_builtin;
mod return_in_try_except_finally;
mod use_contextlib_suppress;
mod yoda_conditions;
